ewa.ply.cpp.Preprocessor

Package ewa :: Package ply :: Module cpp :: Class Preprocessor |
[hide private]
[frames] | no frames]

# Class Preprocessor

source code

    object --+
             |
            Preprocessor

Instance Methods | [hide private]
__init__(self, lexer=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
tokenize(self, text) | source code
error(self, file, line, msg) | source code
lexprobe(self) | source code
add_path(self, path) | source code
group_lines(self, input) | source code
tokenstrip(self, tokens) | source code
collect_args(self, tokenlist) | source code
macro_prescan(self, macro) | source code
macro_expand_args(self, macro, args) | source code
expand_macros(self, tokens, expanded=None) | source code
evalexpr(self, tokens) | source code
parsegen(self, input, source=None) | source code
include(self, tokens) | source code
define(self, tokens) | source code
undef(self, tokens) | source code
parse(self, input, source=None, ignore=`{``}`) | source code
token(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, lexer=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)